# ChaptersCountResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**num_chapters** | **int** |  | 

## Example

```python
from openapi_client.models.chapters_count_response import ChaptersCountResponse

# TODO update the JSON string below
json = "{}"
# create an instance of ChaptersCountResponse from a JSON string
chapters_count_response_instance = ChaptersCountResponse.from_json(json)
# print the JSON string representation of the object
print(ChaptersCountResponse.to_json())

# convert the object into a dict
chapters_count_response_dict = chapters_count_response_instance.to_dict()
# create an instance of ChaptersCountResponse from a dict
chapters_count_response_from_dict = ChaptersCountResponse.from_dict(chapters_count_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


